package rition.backend.service;

import org.springframework.stereotype.Service;
import rition.common.data.dto.MetricDataDto;
import rition.common.data.dto.MetricDataProto;
import rition.service.collector.MetricCollectingService;

/**
 * MetricCollectorService 指标数据收集类，负责收集来自云主机探针上报的数据，并将其入库等，
 * 这里只是个代理类，实际的实现在collector模块，
 * 这样做只是为了方便日后将collector等模块独立拆分出来，
 * 这种情况下实际上数据收集的入口应当直接放在collector里，而不是api部分
 */
@Service
public class MetricDataCollectingService {

    private final MetricCollectingService metricCollectingService;

    public MetricDataCollectingService(MetricCollectingService metricCollectingService) {
        this.metricCollectingService = metricCollectingService;
    }

    /**
     * 接收处理好的监控指标数据
     * @param collectedMetricData 监控指标数据，protobuf对象
     */
    public void receiveData(MetricDataDto collectedMetricData) {
        metricCollectingService.receiveData(collectedMetricData);
    }
}
